<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="企业名称:" prop="companyId" v-if="state.isAdmin">
          <el-select
              v-model="state.form.companyId"
              filterable
              clearable
              style="width: 100%"
              :disabled="state.title  == '查看' || state.title  == '编辑' || !state.isAdmin"
              @change="selectValueCom"
          >
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="人员选择:" prop="personId">
          <el-select
              clearable
              v-model="state.form.personId"
              :disabled="state.title  =='查看'"
              filterable
              style="width: 100%"
          >
            <el-option
                v-for="item in state.peopleList"
                :key="item.id"
                :label="item.name"
                :value="item.id"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="专长领域:" prop="speciality">
          <el-input v-model.trim="state.form.speciality" :disabled="state.title =='查看'" placeholder="专长领域"></el-input>
        </el-form-item>
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import {ElMessage} from "element-plus";
import {addUser, editUser, getUser, getUserById, resetPwd} from "@/api/onlineEducation/user"
import {Base64} from "js-base64"
import {getCompany} from "@/api/onlineEducation/company";
import {updateInfoPlatforms, updateSysClause} from "@/api/staffManage/staff";
import Cookies from "js-cookie";
import {addPerson, editPerson} from "@/api/selfProblems/nameList";
import {addScenario, editScenario} from "@/api/selfProblems/scenario";
import {getStudent} from "@/api/onlineEducation/student";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()
const state = reactive({
  title: '',
  form: {
    id: null,
    personId: null,
    companyId: null,
    speciality: ''
  },
  isAdmin: false,
  peopleList: [],
  formRules:{
    personId: [{ required: true, message: '请选择人员', trigger: 'blur' }],
    companyId: [{ required: true, message: '请选择公司', trigger: 'blur' }],
    speciality: [{ required: true, message: '请输入专长领域', trigger: 'blur' }],
  }
})
onMounted(() => {

});

const openDialog = async (type, value,companyList) => {
  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyName = userInfo.companyName
  state.form.companyId = userInfo.companyId
  if(state.isAdmin){
    state.companyList = companyList
    state.form.companyId = value.companyId
    state.form.companyName = value.companyName
  }
  if(state.title == '编辑'||state.title == '查看'){
    Object.keys(state.form).forEach(key => {
      if (key in value) {
        state.form[key] = value[key]
      }
    })
  }
  await   getPeopleList()
  dialogVisible.value = true
}

const getPeopleList = async ()=> {
  if(state.isAdmin && !state.form.companyId && (state.form.companyId == 0 || state.form.companyId == null)){
    return
  }
  const queryParams = {
    pageNum: 1,
    pageSize: 9999,
    companyId: state.form.companyId
  }
  const res = await getStudent(queryParams)
  if(res.code == 200){
    state.peopleList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
};
const onSubmit = async () => {
  const valid = await superRef.value.validate();
  if(valid) {
    if (state.title  === '新增') {
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addPerson(data)
      if (res.code === 200) {
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      } else {
        ElMessage.warning(res.message)
      }
      emit("getList")
      handleClose()
    } else if (state.title === '编辑') {
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editPerson(data)
      if (res.code === 200) {
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      } else {
        ElMessage.warning(res.message)
      }
      emit("getList")
      handleClose()
    }
  }
}
const selectValueCom = (val) => {
  state.form.personId = null
  getPeopleList()
}

const handleClose = () => {
  state.form = {
    id: null,
    personId: null,
    companyId: null,
    speciality: ''
  }
  state.peopleList = []
  superRef.value.clearValidate();
  dialogVisible.value = false;

}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
